import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal
} from 'd3';

const width = 1000; 
const height = 500;

const margin = {left:20, right:20, top:20, bottom:20}
const xAxisTickFormat = number => number;

let svg = select("body").append("svg")

svg		.attr("width", width + margin.left + margin.right)
		.attr("height", height + margin.top + margin.bottom)

const render = data => {
const pieData = pie().sort(null).value(d=>d.value)(data);

const colors = scaleOrdinal()  
  .domain(data)
  .range([
    "#43fede", 
    "#f91000",
    "#a6d269", 
    "#e7ee0b",
    "#150796"
  ]);

const segments = arc()
  .innerRadius(0)
  .outerRadius(161)
  .padAngle(0)
  .padRadius(0);


const sections = svg.append("g")
  .attr("transform", `translate(324,309)`)
  .selectAll("path").data(pieData);

const pathsSlice = sections
  .enter().append("path")
    .attr("d", segments)  
    .attr("fill", d => colors(d.data.value))
    .attr("opacity", 0);

pathsSlice.transition()
    .duration(2000)  
    .delay((d,i)=>i*1000) 
  .attr("opacity", 1);

pathsSlice.append('title')
   .text(d => d.data.label + "\n"+d.data.value)
  
const legends = svg.append("g")
  .attr("transform", "translate(623,151)")
  .selectAll(".legends").data(pieData); 

const legend = legends.enter().append("g")
  .attr("transform", (d,i)=>{
    return `translate(0,${(i+1)*30})`;
  })
  .on("mouseenter", d => {
    const selectedLabel = d.data.label;
    pathsSlice.transition()
      .attr("opacity", d => d.data.label === selectedLabel ? 1 : 0.2) 
  })
  
  .on("mouseout", d => {
    pathsSlice.transition()
      .attr("opacity", 1) 
  })
;
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.value));
  
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.label);
  
  legend.append("text")
  	.attr("x", 200)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat(d.data.value));
  
let title = "Farmer's suicides in Maharashtra : Jan-Mar 2018" 
  
  svg.append('text') 
     .text(title) 
     .attr("y", 50) 
     .attr("x", 400)
     .attr("class","title")
      
}
  
json( 'data.json' ).then(data => {
  // Transformar strings a numeros
  data.forEach(d=>{
    d.value = +d.value;
  });
//Sorting data
  data.sort(function(x, y){
   return d3.descending(x.value, y.value);
  })
  render(data);
})